import warnings
from rand.rand import Rand, ParseFnType

warnings.simplefilter(action='ignore', category=FutureWarning)
